netapp_ontap.models.anti_ransomware_storage_unit API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.anti_ransomware_storage_unit`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AntiRansomwareStorageUnitSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AntiRansomwareStorageUnit object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `attack_probability: str GET`

    The probability of a ransomware attack.
    Possible values:

    - `none` No suspected ransomware activity.
    - `moderate` Suspected ransomware activity.

    Valid choices:

    - none
    - moderate
  `attack_reports: List[AntiRansomwareStorageUnitAttackReports] GET`

    The attack_reports field of the anti_ransomware_storage_unit.

  `state: str GET PATCH`

    The anti-ransomware state for the storage unit.
    Possible values:

    - `disabled` Anti-ransomware monitoring is disabled for the storage unit. Valid in PATCH and GET.
    - `disable_in_progress` Anti-ransomware monitoring is being disabled and a clean-up operation is in progress. Valid in GET.
    - `enabled` Anti-ransomware monitoring is active for the storage unit. Valid in PATCH and GET.
    - `paused` Anti-ransomware monitoring is paused for the storage unit from its earlier enabled state. Valid in PATCH and GET.

    Valid choices:

    - disabled
    - disable_in_progress
    - enabled
    - paused